@@ -32,6 +32,7 @@ func newBuildsCommand() *cobra.Command {
 	cmd.AddCommand(newBuildsCancelCommand())
 	cmd.AddCommand(newBuildsShowCommand())
 	cmd.AddCommand(newBuildsListCommand())
+	cmd.AddCommand(newBuildsUpdateCommand())
 	cmd.AddCommand(newBuildsSecretCommand())
 	cmd.AddCommand(newBuildsSSHCommand())
 	cmd.AddCommand(newBuildsArtifactsCommand())
@@ -47,7 +48,7 @@ const buildsSubmitPrefill = `
 `
 
 func newBuildsSubmitCommand() *cobra.Command {
-	var follow, edit bool
+	var follow, edit, disableSecrets bool
 	var note, tagString, visibility string
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
@@ -63,9 +64,16 @@ func newBuildsSubmitCommand() *cobra.Command {
 			if _, err := os.Stat(".build.yml"); err == nil {
 				filenames = append(filenames, ".build.yml")
 			}
+			if _, err := os.Stat(".build.yaml"); err == nil {
+				filenames = append(filenames, ".build.yaml")
+			}
+
 			if matches, err := filepath.Glob(".builds/*.yml"); err == nil {
 				filenames = append(filenames, matches...)
 			}
+			if matches, err := filepath.Glob(".builds/*.yaml"); err == nil {
+				filenames = append(filenames, matches...)
+			}
 		}
 
 		if len(filenames) == 0 && !edit {
@@ -108,7 +116,7 @@ func newBuildsSubmitCommand() *cobra.Command {
 		}
 
 		for _, manifest := range manifests {
-			job, err := buildssrht.Submit(c.Client, ctx, manifest, tags, &note, &buildsVisibility)
+			job, err := buildssrht.Submit(c.Client, ctx, manifest, tags, &note, &buildsVisibility, !disableSecrets)
 			if err != nil {
 				log.Fatal(err)
 			}
@@ -140,6 +148,7 @@ func newBuildsSubmitCommand() *cobra.Command {
 	}
 	cmd.Flags().BoolVarP(&follow, "follow", "f", false, "follow build logs")
 	cmd.Flags().BoolVarP(&edit, "edit", "e", false, "edit manifest")
+	cmd.Flags().BoolVarP(&disableSecrets, "no-secrets", "s", false, "disable secrets")
 	cmd.Flags().StringVarP(&note, "note", "n", "", "short job description")
 	cmd.RegisterFlagCompletionFunc("note", cobra.NoFileCompletions)
 	cmd.Flags().StringVarP(&tagString, "tags", "t", "", "job tags (slash separated)")
@@ -150,7 +159,7 @@ func newBuildsSubmitCommand() *cobra.Command {
 }
 
 func newBuildsResubmitCommand() *cobra.Command {
-	var follow, edit bool
+	var follow, edit, disableSecrets bool
 	var note, visibility string
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
@@ -197,7 +206,7 @@ func newBuildsResubmitCommand() *cobra.Command {
 			}
 		}
 
-		job, err := buildssrht.Submit(c.Client, ctx, oldJob.Manifest, nil, &note, &buildsVisibility)
+		job, err := buildssrht.Submit(c.Client, ctx, oldJob.Manifest, nil, &note, &buildsVisibility, !disableSecrets)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -229,6 +238,7 @@ func newBuildsResubmitCommand() *cobra.Command {
 	}
 	cmd.Flags().BoolVarP(&follow, "follow", "f", false, "follow build logs")
 	cmd.Flags().BoolVarP(&edit, "edit", "e", false, "edit manifest")
+	cmd.Flags().BoolVarP(&disableSecrets, "no-secrets", "s", false, "disable secrets")
 	cmd.Flags().StringVarP(&note, "note", "n", "", "short job description")
 	cmd.RegisterFlagCompletionFunc("note", cobra.NoFileCompletions)
 	cmd.Flags().StringVarP(&visibility, "visibility", "v", "", "builds visibility")
@@ -268,7 +278,10 @@ func newBuildsCancelCommand() *cobra.Command {
 }
 
 func newBuildsShowCommand() *cobra.Command {
-	var follow bool
+	var (
+		follow bool
+		web    bool
+	)
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -318,6 +331,18 @@ func newBuildsShowCommand() *cobra.Command {
 			}
 		}
 
+		buildUrl := fmt.Sprintf("%s/%s/job/%d", c.BaseURL, job.Owner.CanonicalName, job.Id)
+		if web {
+			err := openURL(buildUrl)
+			if err != nil {
+				log.Fatal(err)
+			}
+			os.Exit(0)
+		}
+
+		// prints url for easy access
+		fmt.Printf("%s\n\n", buildUrl)
+
 		printJob(os.Stdout, job)
 
 		failedTask := -1
@@ -352,11 +377,21 @@ func newBuildsShowCommand() *cobra.Command {
 		Run:               run,
 	}
 	cmd.Flags().BoolVarP(&follow, "follow", "f", false, "follow job status")
+	cmd.Flags().BoolVar(&web, "web", false, "open in browser")
 	return cmd
 }
 
 func newBuildsListCommand() *cobra.Command {
+	var status string
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
+		if status != "" {
+			_, err := buildssrht.ParseJobStatus(status)
+			if err != nil {
+				log.Fatal(err)
+			}
+		}
+
 		ctx := cmd.Context()
 		c := createClient("builds", cmd)
 		var cursor *buildssrht.Cursor
@@ -384,16 +419,20 @@ func newBuildsListCommand() *cobra.Command {
 			}
 
 			for _, job := range jobs.Results {
+				// TODO: filter with API
+				if status != "" && !strings.EqualFold(status, string(job.Status)) {
+					continue
+				}
 				printJob(p, &job)
 			}
 
 			cursor = jobs.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(jobs.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 
 		if err != nil {
 			log.Fatal(err)
@@ -407,6 +446,52 @@ func newBuildsListCommand() *cobra.Command {
 		ValidArgsFunction: cobra.NoFileCompletions,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of jobs to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
+	cmd.Flags().StringVarP(&status, "status", "s", "", "job status")
+	cmd.RegisterFlagCompletionFunc("status", completeJobStatus)
+	return cmd
+}
+
+func newBuildsUpdateCommand() *cobra.Command {
+	var visibility string
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+
+		id, instance, err := parseBuildID(args[0])
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		c := createClientWithInstance("builds", cmd, instance)
+
+		jobVisibility, err := buildssrht.ParseVisibility(visibility)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		job, err := buildssrht.Update(c.Client, ctx, id, jobVisibility)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		if job == nil {
+			log.Fatalln("failed to update visibility")
+		}
+
+		log.Printf("Updated job %d visibility\n", job.Id)
+	}
+
+	cmd := &cobra.Command{
+		Use:               "update <ID>",
+		Short:             "Update a job's visibility",
+		Args:              cobra.ExactArgs(1),
+		ValidArgsFunction: completeAnyJobs,
+		Run:               run,
+	}
+	cmd.Flags().StringVarP(&visibility, "visibility", "v", "", "job visibility")
+	cmd.MarkFlagRequired("visibility")
+	cmd.RegisterFlagCompletionFunc("visibility", completeVisibility)
 	return cmd
 }
 
@@ -546,6 +631,7 @@ func newBuildsUserWebhookCreateCommand() *cobra.Command {
 }
 
 func newBuildsUserWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("builds", cmd)
@@ -562,12 +648,12 @@ func newBuildsUserWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -580,6 +666,8 @@ func newBuildsUserWebhookListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -651,6 +739,7 @@ func newBuildsSecretCommand() *cobra.Command {
 }
 
 func newBuildsSecretListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("builds", cmd)
@@ -670,12 +759,12 @@ func newBuildsSecretListCommand() *cobra.Command {
 			}
 
 			cursor = secrets.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(secrets.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -687,6 +776,8 @@ func newBuildsSecretListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of secrets to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -950,6 +1041,16 @@ func followJobShow(ctx context.Context, c *Client, id int32) (*buildssrht.Job, e
 	}
 }
 
+var completeJobStatus = cobra.FixedCompletions([]string{
+	"pending",
+	"queued",
+	"running",
+	"success",
+	"failed",
+	"timeout",
+	"cancelled",
+}, cobra.ShellCompDirectiveNoFileComp)
+
 func completeRunningJobs(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	return completeJobs(cmd, true)
 }
@@ -999,7 +1100,7 @@ func completeJobs(cmd *cobra.Command, onlyRunning bool) ([]string, cobra.ShellCo
 
 func completeBuildsUserWebhookEvents(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	var eventList []string
-	events := [1]string{"job_created"}
+	events := [2]string{"job_created", "job_updated"}
 	set := strings.ToLower(cmd.Flag("events").Value.String())
 	for _, event := range events {
 		if !strings.Contains(set, event) {
