@@ -30,10 +30,12 @@ func newGitCommand() *cobra.Command {
 	cmd.AddCommand(newGitListCommand())
 	cmd.AddCommand(newGitDeleteCommand())
 	cmd.AddCommand(newGitCloneCommand())
+	cmd.AddCommand(newGitSetupCommand())
 	cmd.AddCommand(newGitACLCommand())
 	cmd.AddCommand(newGitShowCommand())
 	cmd.AddCommand(newGitUserWebhookCommand())
 	cmd.AddCommand(newGitUpdateCommand())
+	cmd.AddCommand(newGitWebhookCommand())
 	cmd.PersistentFlags().StringP("repo", "r", "", "name of repository")
 	cmd.RegisterFlagCompletionFunc("repo", completeGitRepo)
 	return cmd
@@ -115,6 +117,7 @@ func newGitCreateCommand() *cobra.Command {
 }
 
 func newGitListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		var cursor *gitsrht.Cursor
@@ -149,12 +152,12 @@ func newGitListCommand() *cobra.Command {
 			}
 
 			cursor = repos.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(repos.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -167,6 +170,8 @@ func newGitListCommand() *cobra.Command {
 		ValidArgsFunction: cobra.NoFileCompletions,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of repos to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -195,7 +200,10 @@ func newGitDeleteCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("git", cmd, instance)
-		id := getGitRepoID(c, ctx, name, owner)
+		id, err := getGitRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		if !autoConfirm && !getConfirmation(fmt.Sprintf("Do you really want to delete the repo %s", name)) {
 			log.Println("Aborted")
@@ -287,6 +295,80 @@ func newGitCloneCommand() *cobra.Command {
 	return cmd
 }
 
+func newGitSetupCommand() *cobra.Command {
+	var force bool
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+		success := false
+
+		checkCmd := exec.Command("git", "config", "sendemail.to")
+		checkCmd.Stdin = os.Stdin
+		checkCmd.Stderr = os.Stderr
+
+		b, err := checkCmd.Output()
+		if err != nil {
+			log.Fatalf("failed to check current git settings: %v", err)
+		}
+
+		if strings.TrimSpace(string(b)) != "" && !force {
+			log.Println("Repository is already configured. Skipping setup.")
+			return
+		}
+
+		// TODO: hub.sr.ht API, .b4-config
+		cfg, err := loadProjectConfig()
+		if err != nil {
+			log.Fatalf("failed to load project config: %v", err)
+		}
+
+		if cfg != nil {
+			if cfg.DevList != "" {
+				sendemailCmd := exec.Command("git", "config", "sendemail.to", cfg.DevList)
+				sendemailCmd.Stdin = os.Stdin
+				sendemailCmd.Stdout = os.Stdout
+				sendemailCmd.Stderr = os.Stderr
+
+				err = sendemailCmd.Run()
+				if err != nil {
+					log.Fatalf("failed to set %q: %v", "git config sendemail.to", err)
+				}
+				success = true
+			}
+
+			if cfg.PatchPrefix {
+				name, _, _, err := guessGitRepoName(ctx, cmd)
+				if err != nil {
+					log.Fatalf("failed to get repository name: %v", err)
+				}
+
+				prefixCmd := exec.Command("git", "config", "format.subjectPrefix", fmt.Sprintf("PATCH %s", name))
+				prefixCmd.Stdin = os.Stdin
+				prefixCmd.Stdout = os.Stdout
+				prefixCmd.Stderr = os.Stderr
+
+				err = prefixCmd.Run()
+				if err != nil {
+					log.Fatalf("failed to set %q: %v", "git config format.subjectPrefix", err)
+				}
+			}
+		}
+
+		if success {
+			log.Println("Configured repository")
+		} else {
+			log.Fatalln("Failed to configure repository")
+		}
+	}
+	cmd := &cobra.Command{
+		Use:   "setup",
+		Short: "Setup a repository for `git send-email`",
+		Args:  cobra.ExactArgs(0),
+		Run:   run,
+	}
+	cmd.Flags().BoolVarP(&force, "force", "f", false, "force setup even if already configured")
+	return cmd
+}
+
 func newGitArtifactCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "artifact",
@@ -309,7 +391,10 @@ func newGitArtifactUploadCommand() *cobra.Command {
 
 		c := createClientWithInstance("git", cmd, instance)
 		c.HTTP.Timeout = fileTransferTimeout
-		repoID := getGitRepoID(c, ctx, repoName, owner)
+		repoID, err := getGitRepoID(c, ctx, repoName, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		if rev == "" {
 			var err error
@@ -441,6 +526,7 @@ func newGitACLCommand() *cobra.Command {
 }
 
 func newGitACLListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		var name, owner, instance string
@@ -485,12 +571,12 @@ func newGitACLListCommand() *cobra.Command {
 			}
 
 			cursor = user.Repository.Acls.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.Repository.Acls.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -503,6 +589,8 @@ func newGitACLListCommand() *cobra.Command {
 		ValidArgsFunction: completeGitRepo,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of ACL entries to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -537,7 +625,10 @@ func newGitACLUpdateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("git", cmd, instance)
-		id := getGitRepoID(c, ctx, name, owner)
+		id, err := getGitRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		acl, err := gitsrht.UpdateACL(c.Client, ctx, id, accessMode, args[0])
 		if err != nil {
@@ -591,6 +682,7 @@ func newGitACLDeleteCommand() *cobra.Command {
 }
 
 func newGitShowCommand() *cobra.Command {
+	var web bool
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -626,6 +718,18 @@ func newGitShowCommand() *cobra.Command {
 			log.Fatalf("no such repository %q", name)
 		}
 		repo := user.Repository
+		repoUrl := fmt.Sprintf("%s/%s/%s", c.BaseURL, owner, name)
+
+		if web {
+			err := openURL(repoUrl)
+			if err != nil {
+				log.Fatal(err)
+			}
+			os.Exit(0)
+		}
+
+		// prints url for easy access
+		fmt.Printf("%s\n\n", repoUrl)
 
 		// prints basic information
 		fmt.Printf("%s (%s)\n", termfmt.Bold.String(repo.Name), repo.Visibility.TermString())
@@ -675,6 +779,7 @@ func newGitShowCommand() *cobra.Command {
 		ValidArgsFunction: completeGitRepo,
 		Run:               run,
 	}
+	cmd.Flags().BoolVar(&web, "web", false, "open in browser")
 
 	return cmd
 }
@@ -734,6 +839,7 @@ func newGitUserWebhookCreateCommand() *cobra.Command {
 }
 
 func newGitUserWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("git", cmd)
@@ -750,12 +856,12 @@ func newGitUserWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -767,6 +873,8 @@ func newGitUserWebhookListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -799,7 +907,7 @@ func newGitUserWebhookDeleteCommand() *cobra.Command {
 }
 
 func newGitUpdateCommand() *cobra.Command {
-	var visibility, branch, readme, description string
+	var visibility, branch, readme, description, newName string
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -815,7 +923,10 @@ func newGitUpdateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("git", cmd, instance)
-		id := getGitRepoID(c, ctx, name, owner)
+		id, err := getGitRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 		var input gitsrht.RepoInput
 
 		if visibility != "" {
@@ -841,6 +952,10 @@ func newGitUpdateCommand() *cobra.Command {
 			input.HEAD = &branch
 		}
 
+		if newName != "" {
+			input.Name = &newName
+		}
+
 		if readme == "" && cmd.Flags().Changed("readme") {
 			_, err := gitsrht.ClearCustomReadme(c.Client, ctx, id)
 			if err != nil {
@@ -888,6 +1003,164 @@ func newGitUpdateCommand() *cobra.Command {
 	cmd.Flags().StringVar(&readme, "readme", "", "update the custom README")
 	cmd.Flags().StringVarP(&description, "description", "d", "", "repository description")
 	cmd.RegisterFlagCompletionFunc("description", cobra.NoFileCompletions)
+	cmd.Flags().StringVarP(&newName, "name", "n", "", "repository name")
+	cmd.RegisterFlagCompletionFunc("name", cobra.NoFileCompletions)
+	return cmd
+}
+
+func newGitWebhookCommand() *cobra.Command {
+	cmd := &cobra.Command{
+		Use:   "webhook",
+		Short: "Manage git webhooks",
+	}
+	cmd.AddCommand(newGitWebhookCreateCommand())
+	cmd.AddCommand(newGitWebhookListCommand())
+	cmd.AddCommand(newGitWebhookDeleteCommand())
+	return cmd
+}
+
+func newGitWebhookCreateCommand() *cobra.Command {
+	var events []string
+	var stdin bool
+	var url string
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+
+		var name, owner, instance string
+		if len(args) > 0 {
+			name, owner, instance = parseResourceName(args[0])
+		} else {
+			var err error
+			name, owner, instance, err = getGitRepoName(ctx, cmd)
+			if err != nil {
+				log.Fatal(err)
+			}
+		}
+
+		c := createClientWithInstance("git", cmd, instance)
+		id, err := getGitRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		var config gitsrht.GitWebhookInput
+		config.RepositoryID = id
+		config.Url = url
+
+		whEvents, err := gitsrht.ParseGitWebhookEvents(events)
+		if err != nil {
+			log.Fatal(err)
+		}
+		config.Events = whEvents
+		config.Query = readWebhookQuery(stdin)
+
+		webhook, err := gitsrht.CreateGitWebhook(c.Client, ctx, config)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		log.Printf("Created git webhook with ID %d\n", webhook.Id)
+	}
+
+	cmd := &cobra.Command{
+		Use:               "Create [repo]",
+		Short:             "Create a git webhook",
+		Args:              cobra.MaximumNArgs(1),
+		ValidArgsFunction: completeGitRepo,
+		Run:               run,
+	}
+	cmd.Flags().StringSliceVarP(&events, "events", "e", nil, "webhook events")
+	cmd.RegisterFlagCompletionFunc("events", completeGitWebhookEvents)
+	cmd.MarkFlagRequired("events")
+	cmd.Flags().BoolVar(&stdin, "stdin", !isStdinTerminal, "read webhook query from stdin")
+	cmd.Flags().StringVarP(&url, "url", "u", "", "payload url")
+	cmd.RegisterFlagCompletionFunc("url", cobra.NoFileCompletions)
+	cmd.MarkFlagRequired("url")
+	return cmd
+}
+
+func newGitWebhookListCommand() *cobra.Command {
+	var count int
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+
+		var name, owner, instance string
+		if len(args) > 0 {
+			name, owner, instance = parseResourceName(args[0])
+		} else {
+			var err error
+			name, owner, instance, err = getGitRepoName(ctx, cmd)
+			if err != nil {
+				log.Fatal(err)
+			}
+		}
+
+		c := createClientWithInstance("git", cmd, instance)
+		id, err := getGitRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		var cursor *gitsrht.Cursor
+		err = pagerify(func(p pager) error {
+			webhooks, err := gitsrht.GitWebhooks(c.Client, ctx, id, cursor)
+			if err != nil {
+				return err
+			}
+
+			for _, webhook := range webhooks.Results {
+				fmt.Fprintf(p, "%s %s\n", termfmt.DarkYellow.Sprintf("#%d", webhook.Id), webhook.Url)
+			}
+
+			cursor = webhooks.Cursor
+			if p.IsDone(cursor, len(webhooks.Results)) {
+				return pagerDone
+			}
+
+			return nil
+		}, count)
+		if err != nil {
+			log.Fatal(err)
+		}
+	}
+
+	cmd := &cobra.Command{
+		Use:               "list [repo]",
+		Short:             "List git webhooks",
+		Args:              cobra.MaximumNArgs(1),
+		ValidArgsFunction: completeGitRepo,
+		Run:               run,
+	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
+	return cmd
+}
+
+func newGitWebhookDeleteCommand() *cobra.Command {
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+		c := createClient("git", cmd)
+
+		id, err := parseInt32(args[0])
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		webhook, err := gitsrht.DeleteGitWebhook(c.Client, ctx, id)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		log.Printf("Deleted webhook %d\n", webhook.Id)
+	}
+
+	cmd := &cobra.Command{
+		Use:               "delete <ID>",
+		Short:             "Delete a git webhook",
+		Args:              cobra.ExactArgs(1),
+		ValidArgsFunction: cobra.NoFileCompletions,
+		Run:               run,
+	}
 	return cmd
 }
 
@@ -938,7 +1211,7 @@ func guessGitRepoName(ctx context.Context, cmd *cobra.Command) (repoName, owner,
 	return "", "", "", fmt.Errorf("no sr.ht Git repository found in current directory")
 }
 
-func getGitRepoID(c *Client, ctx context.Context, name, owner string) int32 {
+func getGitRepoID(c *Client, ctx context.Context, name, owner string) (int32, error) {
 	var (
 		user     *gitsrht.User
 		username string
@@ -951,25 +1224,33 @@ func getGitRepoID(c *Client, ctx context.Context, name, owner string) int32 {
 		user, err = gitsrht.RepositoryIDByUser(c.Client, ctx, username, name)
 	}
 	if err != nil {
-		log.Fatalf("failed to get repository ID: %v", err)
+		return 0, fmt.Errorf("failed to get repository ID: %v", err)
 	} else if user == nil {
-		log.Fatalf("no such user %q", username)
+		return 0, fmt.Errorf("no such user %q", username)
 	} else if user.Repository == nil {
-		log.Fatalf("no such repository %q", name)
+		return 0, fmt.Errorf("no such repository %q", name)
 	}
-	return user.Repository.Id
+	return user.Repository.Id, nil
 }
 
 func gitRemoteURLs(ctx context.Context) ([]*url.URL, error) {
-	// TODO: iterate over all remotes
-	out, err := exec.CommandContext(ctx, "git", "remote", "get-url", "--all", "origin").Output()
+	var urls []*url.URL
+
+	out, err := exec.CommandContext(ctx, "git", "remote", "-v").Output()
 	if err != nil {
+		eerr, ok := err.(*exec.ExitError)
+		if ok && eerr.ExitCode() == 128 {
+			return urls, nil
+		}
 		return nil, fmt.Errorf("failed to get remote URL: %v", err)
 	}
 
-	var urls []*url.URL
 	l := strings.Split(strings.TrimSpace(string(out)), "\n")
 	for _, raw := range l {
+		_, raw, _ = strings.Cut(raw, "\t") // remote name
+		raw = strings.TrimSuffix(raw, " (fetch)")
+		raw = strings.TrimSuffix(raw, " (push)")
+
 		var u *url.URL
 		switch {
 		case strings.Contains(raw, "://"):
@@ -1110,6 +1391,18 @@ func completeGitUserWebhookID(cmd *cobra.Command, args []string, toComplete stri
 	return webhookList, cobra.ShellCompDirectiveNoFileComp
 }
 
+func completeGitWebhookEvents(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+	var eventList []string
+	events := [2]string{"git_pre_receive", "git_post_receive"}
+	set := strings.ToLower(cmd.Flag("events").Value.String())
+	for _, event := range events {
+		if !strings.Contains(set, event) {
+			eventList = append(eventList, event)
+		}
+	}
+	return eventList, cobra.ShellCompDirectiveNoFileComp
+}
+
 func completeBranches(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	ctx := cmd.Context()
 	repoName, owner, instace, err := getGitRepoName(ctx, cmd)
