@@ -35,6 +35,7 @@ func newHgCommand() *cobra.Command {
 }
 
 func newHgListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("hg", cmd)
@@ -67,12 +68,12 @@ func newHgListCommand() *cobra.Command {
 			}
 
 			cursor = repos.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(repos.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -84,6 +85,8 @@ func newHgListCommand() *cobra.Command {
 		Args:  cobra.MaximumNArgs(1),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of repos to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -176,7 +179,10 @@ func newHgDeleteCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("hg", cmd, instance)
-		id := getHgRepoID(c, ctx, name, owner)
+		id, err := getHgRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		if !autoConfirm && !getConfirmation(fmt.Sprintf("Do you really want to delete the repo %s", name)) {
 			log.Println("Aborted")
@@ -218,7 +224,10 @@ func newHgUpdateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("hg", cmd, instance)
-		id := getHgRepoID(c, ctx, name, owner)
+		id, err := getHgRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		var input hgsrht.RepoInput
 
@@ -311,6 +320,7 @@ func newHgACLCommand() *cobra.Command {
 }
 
 func newHgACLListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		var name, owner, instance string
@@ -355,12 +365,12 @@ func newHgACLListCommand() *cobra.Command {
 			}
 
 			cursor = user.Repository.AccessControlList.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.Repository.AccessControlList.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -373,6 +383,8 @@ func newHgACLListCommand() *cobra.Command {
 		ValidArgsFunction: completeHgRepo,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of ACL entries to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -407,7 +419,10 @@ func newHgACLUpdateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("hg", cmd, instance)
-		id := getHgRepoID(c, ctx, name, owner)
+		id, err := getHgRepoID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		acl, err := hgsrht.UpdateACL(c.Client, ctx, id, accessMode, args[0])
 		if err != nil {
@@ -515,6 +530,7 @@ func newHgUserWebhookCreateCommand() *cobra.Command {
 }
 
 func newHgUserWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("hg", cmd)
@@ -531,12 +547,12 @@ func newHgUserWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -549,6 +565,8 @@ func newHgUserWebhookListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -635,7 +653,7 @@ func hgRemoteUrl(ctx context.Context) (*url.URL, error) {
 	}
 }
 
-func getHgRepoID(c *Client, ctx context.Context, name, owner string) int32 {
+func getHgRepoID(c *Client, ctx context.Context, name, owner string) (int32, error) {
 	var (
 		user     *hgsrht.User
 		username string
@@ -648,13 +666,13 @@ func getHgRepoID(c *Client, ctx context.Context, name, owner string) int32 {
 		user, err = hgsrht.RepositoryIDByUser(c.Client, ctx, username, name)
 	}
 	if err != nil {
-		log.Fatalf("failed to get repository ID: %v", err)
+		return 0, fmt.Errorf("failed to get repository ID: %v", err)
 	} else if user == nil {
-		log.Fatalf("no such user %q", username)
+		return 0, fmt.Errorf("no such user %q", username)
 	} else if user.Repository == nil {
-		log.Fatalf("no such repository %q", name)
+		return 0, fmt.Errorf("no such repository %q", name)
 	}
-	return user.Repository.Id
+	return user.Repository.Id, nil
 }
 
 func completeHgUserWebhookEvents(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
