@@ -59,7 +59,10 @@ func newListsDeleteCommand() *cobra.Command {
 			}
 		}
 		c := createClientWithInstance("lists", cmd, instance)
-		id := getMailingListID(c, ctx, name, owner)
+		id, err := getMailingListID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		if !autoConfirm && !getConfirmation(fmt.Sprintf("Do you really want to delete the list %s", name)) {
 			log.Println("Aborted")
@@ -88,12 +91,16 @@ func newListsDeleteCommand() *cobra.Command {
 }
 
 func newListsListCommand() *cobra.Command {
+	var count int
 	cmd := &cobra.Command{
 		Use:               "list [username]",
 		Short:             "List mailing lists",
 		Args:              cobra.MaximumNArgs(1),
 		ValidArgsFunction: cobra.NoFileCompletions,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of mailing lists to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
+
 	cmd.Run = func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("lists", cmd)
@@ -127,11 +134,11 @@ func newListsListCommand() *cobra.Command {
 			}
 
 			cursor = lists.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(lists.Results)) {
 				return pagerDone
 			}
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -163,7 +170,10 @@ func newListsUpdateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("lists", cmd, instance)
-		id := getMailingListID(c, ctx, name, owner)
+		id, err := getMailingListID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 		// TODO: Support permitMime, rejectMime
 		var input listssrht.MailingListInput
 
@@ -226,7 +236,7 @@ func newListsUpdateCommand() *cobra.Command {
 			}
 		}
 
-		_, err := listssrht.UpdateMailingList(c.Client, ctx, id, input)
+		_, err = listssrht.UpdateMailingList(c.Client, ctx, id, input)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -261,7 +271,10 @@ func newListsSubscribeCommand() *cobra.Command {
 			}
 		}
 		c := createClientWithInstance("lists", cmd, instance)
-		id := getMailingListID(c, ctx, name, owner)
+		id, err := getMailingListID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		subscription, err := listssrht.MailingListSubscribe(c.Client, ctx, id)
 		if err != nil {
@@ -296,7 +309,10 @@ func newListsUnsubscribeCommand() *cobra.Command {
 			}
 		}
 		c := createClientWithInstance("lists", cmd, instance)
-		id := getMailingListID(c, ctx, name, owner)
+		id, err := getMailingListID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		subscription, err := listssrht.MailingListUnsubscribe(c.Client, ctx, id)
 		if err != nil {
@@ -464,10 +480,21 @@ func newListsPatchsetCommand() *cobra.Command {
 }
 
 func newListsPatchsetListCommand() *cobra.Command {
+	var count int
 	var byUser bool
+	var status string
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
+		filterStatus := false
+		if status != "" {
+			_, err := listssrht.ParsePatchsetStatus(status)
+			if err != nil {
+				log.Fatal(err)
+			}
+			filterStatus = true
+		}
+
 		var name, owner, instance string
 		if len(args) > 0 {
 			name, owner, instance = parseMailingListName(args[0])
@@ -532,16 +559,20 @@ func newListsPatchsetListCommand() *cobra.Command {
 			}
 
 			for _, patchset := range patches.Results {
-				printPatchset(p, byUser, &patchset)
+				// TODO: filter with API
+				if status != "" && !strings.EqualFold(status, string(patchset.Status)) {
+					continue
+				}
+				printPatchset(p, &patchset, byUser, filterStatus)
 			}
 
 			cursor = patches.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(patches.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -554,14 +585,22 @@ func newListsPatchsetListCommand() *cobra.Command {
 		ValidArgsFunction: cobra.NoFileCompletions,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of patchsets to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	cmd.Flags().BoolVarP(&byUser, "user", "u", false, "list patches by user")
+	cmd.Flags().StringVarP(&status, "status", "s", "proposed", "patchset status")
+	cmd.RegisterFlagCompletionFunc("status", completePatchsetStatus)
 	return cmd
 }
 
-func printPatchset(w io.Writer, byUser bool, patchset *listssrht.Patchset) {
-	s := fmt.Sprintf("%s\t%s\t", termfmt.DarkYellow.Sprintf("#%d", patchset.Id), patchset.Status.TermString())
+func printPatchset(w io.Writer, patchset *listssrht.Patchset, byUser bool, filterStatus bool) {
+	s := fmt.Sprintf("%s\t", termfmt.DarkYellow.Sprintf("#%d", patchset.Id))
+	if !filterStatus {
+		s += fmt.Sprintf("%s\t", patchset.Status.TermString())
+	}
+
 	if patchset.Prefix != nil && *patchset.Prefix != "" {
-		s += fmt.Sprintf("[%s] ", *patchset.Prefix)
+		s += fmt.Sprintf("[%s] ", strings.TrimSpace(*patchset.Prefix))
 	}
 	s += patchset.Subject
 	if patchset.Version != 1 {
@@ -725,6 +764,7 @@ func newListsACLCommand() *cobra.Command {
 }
 
 func newListsACLListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -780,12 +820,12 @@ func newListsACLListCommand() *cobra.Command {
 			}
 
 			cursor = user.List.Acl.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.List.Acl.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -798,6 +838,8 @@ func newListsACLListCommand() *cobra.Command {
 		ValidArgsFunction: completeList,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of ACL entries to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -895,6 +937,7 @@ func newListsUserWebhookCreateCommand() *cobra.Command {
 }
 
 func newListsUserWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("lists", cmd)
@@ -911,12 +954,12 @@ func newListsUserWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -928,6 +971,8 @@ func newListsUserWebhookListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -989,7 +1034,10 @@ func newListsWebhookCreateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("lists", cmd, instance)
-		id := getMailingListID(c, ctx, name, owner)
+		id, err := getMailingListID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		var config listssrht.MailingListWebhookInput
 		config.Url = url
@@ -1027,6 +1075,7 @@ func newListsWebhookCreateCommand() *cobra.Command {
 }
 
 func newListsWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -1073,12 +1122,12 @@ func newListsWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = user.List.Webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.List.Webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -1091,6 +1140,8 @@ func newListsWebhookListCommand() *cobra.Command {
 		ValidArgsFunction: completeList,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -1123,6 +1174,7 @@ func newListsWebhookDeleteCommand() *cobra.Command {
 }
 
 func newListsSubscriptions() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("lists", cmd)
@@ -1139,12 +1191,12 @@ func newListsSubscriptions() *cobra.Command {
 			}
 
 			cursor = subscriptions.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(subscriptions.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -1156,6 +1208,8 @@ func newListsSubscriptions() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of subscriptions to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -1184,7 +1238,7 @@ func parseMailingListName(s string) (name, owner, instance string) {
 	return name, owner, instance
 }
 
-func getMailingListID(c *Client, ctx context.Context, name, owner string) int32 {
+func getMailingListID(c *Client, ctx context.Context, name, owner string) (int32, error) {
 	var (
 		user     *listssrht.User
 		username string
@@ -1198,16 +1252,16 @@ func getMailingListID(c *Client, ctx context.Context, name, owner string) int32
 		user, err = listssrht.MailingListIDByUser(c.Client, ctx, username, name)
 	}
 	if err != nil {
-		log.Fatal(err)
+		return 0, err
 	} else if user == nil {
-		log.Fatalf("no such user %q", username)
+		return 0, fmt.Errorf("no such user %q", username)
 	} else if user.List == nil {
 		if owner == "" {
-			log.Fatalf("no such mailing list %s", name)
+			return 0, fmt.Errorf("no such mailing list %s", name)
 		}
-		log.Fatalf("no such mailing list %s/%s/%s", c.BaseURL, owner, name)
+		return 0, fmt.Errorf("no such mailing list %s/%s/%s", c.BaseURL, owner, name)
 	}
-	return user.List.Id
+	return user.List.Id, nil
 }
 
 func getMailingListName(ctx context.Context, cmd *cobra.Command) (name, owner, instance string, err error) {
