@@ -13,6 +13,7 @@ import (
 	"strings"
 
 	"git.sr.ht/~emersion/gqlclient"
+	"github.com/dustin/go-humanize"
 	"github.com/spf13/cobra"
 
 	"git.sr.ht/~xenrox/hut/srht/pagessrht"
@@ -28,6 +29,7 @@ func newPagesCommand() *cobra.Command {
 	cmd.AddCommand(newPagesUnpublishCommand())
 	cmd.AddCommand(newPagesListCommand())
 	cmd.AddCommand(newPagesUserWebhookCommand())
+	cmd.AddCommand(newPagesACLCommand())
 	return cmd
 }
 
@@ -234,6 +236,7 @@ func newPagesUnpublishCommand() *cobra.Command {
 }
 
 func newPagesListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("pages", cmd)
@@ -246,16 +249,16 @@ func newPagesListCommand() *cobra.Command {
 			}
 
 			for _, site := range sites.Results {
-				fmt.Fprintf(p, "%s (%s)\n", termfmt.Bold.Sprintf(site.Domain), site.Protocol)
+				fmt.Fprintf(p, "%s %s (%s)\n", termfmt.DarkYellow.Sprintf("#%d", site.Id), termfmt.Bold.Sprintf(site.Domain), site.Protocol)
 			}
 
 			cursor = sites.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(sites.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -266,6 +269,8 @@ func newPagesListCommand() *cobra.Command {
 		Short: "List registered sites",
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of sites to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -324,6 +329,7 @@ func newPagesUserWebhookCreateCommand() *cobra.Command {
 }
 
 func newPagesUserWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("pages", cmd)
@@ -340,12 +346,12 @@ func newPagesUserWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -357,6 +363,8 @@ func newPagesUserWebhookListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -388,6 +396,150 @@ func newPagesUserWebhookDeleteCommand() *cobra.Command {
 	return cmd
 }
 
+func newPagesACLCommand() *cobra.Command {
+	cmd := &cobra.Command{
+		Use:   "acl",
+		Short: "Manage access-control lists",
+	}
+	cmd.AddCommand(newPagesACLUpdateCommand())
+	cmd.AddCommand(newPagesACLDeleteCommand())
+	cmd.AddCommand(newPagesACLListCommand())
+	return cmd
+}
+
+func newPagesACLUpdateCommand() *cobra.Command {
+	var publish bool
+	var siteID int
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+		c := createClient("pages", cmd)
+
+		user, err := pagessrht.UserID(c.Client, ctx, args[0])
+		if err != nil {
+			log.Fatalf("failed to get user ID: %v", err)
+		} else if user == nil {
+			log.Fatal("no such user")
+		}
+
+		var input pagessrht.ACLInput
+		input.Publish = publish
+
+		acl, err := pagessrht.UpdateSiteACL(c.Client, ctx, int32(siteID), user.Id, input)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		log.Printf("Updated access rights for %q\n", acl.Entity.CanonicalName)
+	}
+
+	cmd := &cobra.Command{
+		Use:               "update <user>",
+		Short:             "Update ACL entries",
+		Args:              cobra.ExactArgs(1),
+		ValidArgsFunction: cobra.NoFileCompletions,
+		Run:               run,
+	}
+	cmd.Flags().BoolVar(&publish, "publish", false, "permission to publish the site")
+	cmd.Flags().IntVar(&siteID, "id", 0, "ID of the site")
+	cmd.MarkFlagRequired("id")
+	cmd.RegisterFlagCompletionFunc("id", cobra.NoFileCompletions)
+	return cmd
+}
+
+func newPagesACLDeleteCommand() *cobra.Command {
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+		c := createClient("pages", cmd)
+
+		id, err := parseInt32(args[0])
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		acl, err := pagessrht.DeleteSiteACL(c.Client, ctx, id)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		log.Printf("Deleted ACL entry for %q\n", acl.Entity.CanonicalName)
+	}
+
+	cmd := &cobra.Command{
+		Use:               "delete <ID>",
+		Short:             "Delete an ACL entry",
+		Args:              cobra.ExactArgs(1),
+		ValidArgsFunction: cobra.NoFileCompletions,
+		Run:               run,
+	}
+	return cmd
+}
+
+func newPagesACLListCommand() *cobra.Command {
+	var count int
+	var domain, protocol string
+	run := func(cmd *cobra.Command, args []string) {
+		ctx := cmd.Context()
+		c := createClient("pages", cmd)
+
+		pagesProtocol, err := pagessrht.ParseProtocol(protocol)
+		if err != nil {
+			log.Fatal(err)
+		}
+
+		var cursor *pagessrht.Cursor
+
+		err = pagerify(func(p pager) error {
+			site, err := pagessrht.Acls(c.Client, ctx, domain, pagesProtocol, cursor)
+			if err != nil {
+				return err
+			}
+
+			for _, acl := range site.Acls.Results {
+				printPagesACLEntry(p, &acl)
+			}
+
+			cursor = site.Acls.Cursor
+			if p.IsDone(cursor, len(site.Acls.Results)) {
+				return pagerDone
+			}
+
+			return nil
+		}, count)
+		if err != nil {
+			log.Fatal(err)
+		}
+	}
+
+	cmd := &cobra.Command{
+		Use:   "list",
+		Short: "List ACL entries",
+		Args:  cobra.ExactArgs(0),
+		Run:   run,
+	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of ACL entries to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
+	cmd.Flags().StringVarP(&domain, "domain", "d", "", "domain name")
+	cmd.MarkFlagRequired("domain")
+	cmd.RegisterFlagCompletionFunc("domain", completeDomain)
+	cmd.Flags().StringVarP(&protocol, "protocol", "p", "HTTPS",
+		"protocol (HTTPS or GEMINI)")
+	cmd.RegisterFlagCompletionFunc("protocol", completeProtocol)
+	return cmd
+}
+
+func printPagesACLEntry(w io.Writer, acl *pagessrht.SiteACL) {
+	created := termfmt.Dim.String(humanize.Time(acl.Created.Time))
+
+	var permissions string
+	if acl.Publish {
+		permissions = "publish"
+	} else {
+		permissions = "none"
+	}
+	fmt.Fprintf(w, "%s\t%s\t%s\t%s\n", termfmt.DarkYellow.Sprintf("#%d", acl.Id),
+		acl.Entity.CanonicalName, permissions, created)
+}
+
 var completeProtocol = cobra.FixedCompletions([]string{"https", "gemini"}, cobra.ShellCompDirectiveNoFileComp)
 
 func completeDomain(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
