@@ -133,6 +133,7 @@ func newPasteDeleteCommand() *cobra.Command {
 }
 
 func newPasteListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("paste", cmd)
@@ -150,12 +151,12 @@ func newPasteListCommand() *cobra.Command {
 			}
 
 			cursor = pastes.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(pastes.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -167,6 +168,8 @@ func newPasteListCommand() *cobra.Command {
 		Short: "List pastes",
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of pastes to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -325,6 +328,7 @@ func newPasteUserWebhookCreateCommand() *cobra.Command {
 }
 
 func newPasteUserWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("paste", cmd)
@@ -341,12 +345,12 @@ func newPasteUserWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -358,6 +362,8 @@ func newPasteUserWebhookListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
