@@ -39,6 +39,7 @@ func newTodoCommand() *cobra.Command {
 }
 
 func newTodoListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("todo", cmd)
@@ -71,12 +72,12 @@ func newTodoListCommand() *cobra.Command {
 			}
 
 			cursor = trackers.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(trackers.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -89,6 +90,8 @@ func newTodoListCommand() *cobra.Command {
 		ValidArgsFunction: cobra.NoFileCompletions,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of trackers to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -116,7 +119,10 @@ func newTodoDeleteCommand() *cobra.Command {
 			}
 		}
 		c := createClientWithInstance("todo", cmd, instance)
-		id := getTrackerID(c, ctx, name, owner)
+		id, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		if !autoConfirm && !getConfirmation(fmt.Sprintf("Do you really want to delete the tracker %s", name)) {
 			log.Println("Aborted")
@@ -145,7 +151,7 @@ func newTodoDeleteCommand() *cobra.Command {
 }
 
 func newTodoUpdateCommand() *cobra.Command {
-	var visibility string
+	var visibility, newName string
 	var description bool
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
@@ -161,7 +167,10 @@ func newTodoUpdateCommand() *cobra.Command {
 			}
 		}
 		c := createClientWithInstance("todo", cmd, instance)
-		id := getTrackerID(c, ctx, name, owner)
+		id, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 		var input todosrht.TrackerInput
 
 		if visibility != "" {
@@ -223,6 +232,10 @@ func newTodoUpdateCommand() *cobra.Command {
 			}
 		}
 
+		if newName != "" {
+			input.Name = &newName
+		}
+
 		tracker, err := todosrht.UpdateTracker(c.Client, ctx, id, input)
 		if err != nil {
 			log.Fatal(err)
@@ -240,6 +253,8 @@ func newTodoUpdateCommand() *cobra.Command {
 	cmd.Flags().StringVarP(&visibility, "visibility", "v", "", "tracker visibility")
 	cmd.RegisterFlagCompletionFunc("visibility", completeVisibility)
 	cmd.Flags().BoolVar(&description, "description", false, "edit description")
+	cmd.Flags().StringVarP(&newName, "name", "n", "", "tracker name")
+	cmd.RegisterFlagCompletionFunc("name", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -258,7 +273,10 @@ func newTodoSubscribeCommand() *cobra.Command {
 			}
 		}
 		c := createClientWithInstance("todo", cmd, instance)
-		id := getTrackerID(c, ctx, name, owner)
+		id, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		subscription, err := todosrht.TrackerSubscribe(c.Client, ctx, id)
 		if err != nil {
@@ -295,7 +313,10 @@ func newTodoUnsubscribeCommand() *cobra.Command {
 			}
 		}
 		c := createClientWithInstance("todo", cmd, instance)
-		id := getTrackerID(c, ctx, name, owner)
+		id, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		subscription, err := todosrht.TrackerUnsubscribe(c.Client, ctx, id)
 		if err != nil {
@@ -399,13 +420,18 @@ func newTodoTicketCommand() *cobra.Command {
 }
 
 func newTodoTicketListCommand() *cobra.Command {
+	var count int
 	var status string
 	run := func(cmd *cobra.Command, args []string) {
+		filterStatus := false
 		if status != "" {
-			_, err := todosrht.ParseTicketStatus(status)
-			if err != nil {
-				log.Fatal(err)
+			if status != "open" {
+				_, err := todosrht.ParseTicketStatus(status)
+				if err != nil {
+					log.Fatal(err)
+				}
 			}
+			filterStatus = true
 		}
 
 		ctx := cmd.Context()
@@ -441,19 +467,21 @@ func newTodoTicketListCommand() *cobra.Command {
 
 			for _, ticket := range user.Tracker.Tickets.Results {
 				// TODO: filter with API
-				if status != "" && !strings.EqualFold(status, string(ticket.Status)) {
+				if status == "open" && !ticket.IsOpen() {
+					continue
+				} else if status != "open" && status != "" && !strings.EqualFold(status, string(ticket.Status)) {
 					continue
 				}
-				printTicket(p, &ticket)
+				printTicket(p, &ticket, filterStatus)
 			}
 
 			cursor = user.Tracker.Tickets.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.Tracker.Tickets.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -466,16 +494,22 @@ func newTodoTicketListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
-	cmd.Flags().StringVarP(&status, "status", "s", "", "ticket status")
+	cmd.Flags().IntVar(&count, "count", 0, "number of tickets to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
+	cmd.Flags().StringVarP(&status, "status", "s", "open", "ticket status")
 	cmd.RegisterFlagCompletionFunc("status", completeTicketStatus)
 	return cmd
 }
 
-func printTicket(w io.Writer, ticket *todosrht.Ticket) {
+func printTicket(w io.Writer, ticket *todosrht.Ticket, filterStatus bool) {
 	var labels string
-	s := termfmt.DarkYellow.Sprintf("#%d %s ", ticket.Id, ticket.Status.TermString())
-	if ticket.Status == todosrht.TicketStatusResolved && ticket.Resolution != todosrht.TicketResolutionClosed {
-		s += termfmt.Green.Sprintf("%s ", strings.ToLower(string(ticket.Resolution)))
+	s := termfmt.DarkYellow.Sprintf("#%d ", ticket.Id)
+
+	if !filterStatus {
+		s += fmt.Sprintf("%s ", ticket.Status.TermString())
+		if ticket.Status == todosrht.TicketStatusResolved && ticket.Resolution != todosrht.TicketResolutionClosed {
+			s += termfmt.Green.Sprintf("%s ", strings.ToLower(string(ticket.Resolution)))
+		}
 	}
 
 	if len(ticket.Labels) > 0 {
@@ -504,7 +538,10 @@ func newTodoTicketCommentCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		var input todosrht.SubmitCommentInput
 
@@ -621,7 +658,10 @@ func newTodoTicketStatusCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		event, err := todosrht.UpdateTicketStatus(c.Client, ctx, trackerID, ticketID, input)
 		if err != nil {
@@ -655,7 +695,10 @@ func newTodoTicketSubscribeCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		subscription, err := todosrht.TicketSubscribe(c.Client, ctx, trackerID, ticketID)
 		if err != nil {
@@ -687,7 +730,10 @@ func newTodoTicketUnsubscribeCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		subscription, err := todosrht.TicketUnsubscribe(c.Client, ctx, trackerID, ticketID)
 		if err != nil {
@@ -720,7 +766,10 @@ func newTodoTicketAssignCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		user, err := todosrht.UserIDByName(c.Client, ctx, userName)
 		if err != nil {
@@ -763,7 +812,10 @@ func newTodoTicketUnassignCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		user, err := todosrht.UserIDByName(c.Client, ctx, userName)
 		if err != nil {
@@ -806,7 +858,10 @@ func newTodoTicketDeleteCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		if !autoConfirm && !getConfirmation(fmt.Sprintf("Do you really want to delete the ticket with ID %d", ticketID)) {
 			log.Println("Aborted")
@@ -835,6 +890,7 @@ func newTodoTicketDeleteCommand() *cobra.Command {
 }
 
 func newTodoTicketShowCommand() *cobra.Command {
+	var web bool
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -863,6 +919,15 @@ func newTodoTicketShowCommand() *cobra.Command {
 			log.Fatalf("no such tracker %q", name)
 		}
 
+		todoUrl := fmt.Sprintf("%s/%s/%s/%d", c.BaseURL, owner, name, ticketID)
+		if web {
+			err := openURL(todoUrl)
+			if err != nil {
+				log.Fatal(err)
+			}
+			os.Exit(0)
+		}
+
 		ticket := user.Tracker.Ticket
 		fmt.Printf("%s\n", termfmt.Bold.String(ticket.Subject))
 		fmt.Printf("%s/%s/%s/%d\n\n", c.BaseURL, owner, name, ticketID)
@@ -927,6 +992,8 @@ func newTodoTicketShowCommand() *cobra.Command {
 		ValidArgsFunction: completeTicketID,
 		Run:               run,
 	}
+	cmd.Flags().BoolVar(&web, "web", false, "open in browser")
+
 	return cmd
 }
 
@@ -954,7 +1021,10 @@ func newTodoTicketWebhookCreateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		var config todosrht.TicketWebhookInput
 		config.Url = url
@@ -992,6 +1062,7 @@ func newTodoTicketWebhookCreateCommand() *cobra.Command {
 }
 
 func newTodoTicketWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -1030,12 +1101,12 @@ func newTodoTicketWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = user.Tracker.Ticket.Webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.Tracker.Ticket.Webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -1048,6 +1119,8 @@ func newTodoTicketWebhookListCommand() *cobra.Command {
 		ValidArgsFunction: completeTicketID,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -1092,6 +1165,7 @@ func newTodoLabelCommand() *cobra.Command {
 }
 
 func newTodoLabelListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		name, owner, instance, err := getTrackerName(ctx, cmd)
@@ -1129,12 +1203,12 @@ func newTodoLabelListCommand() *cobra.Command {
 			}
 
 			cursor = user.Tracker.Labels.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.Tracker.Labels.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -1146,6 +1220,8 @@ func newTodoLabelListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of labels to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -1241,7 +1317,10 @@ func newTodoLabelCreateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		id := getTrackerID(c, ctx, name, owner)
+		id, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		if fg == "" {
 			fg = calcLabelForeground(bg)
@@ -1283,6 +1362,7 @@ func newTodoACLCommand() *cobra.Command {
 }
 
 func newTodoACLListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		var name, owner, instance string
@@ -1337,12 +1417,12 @@ func newTodoACLListCommand() *cobra.Command {
 			}
 
 			cursor = user.Tracker.Acls.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.Tracker.Acls.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -1355,6 +1435,8 @@ func newTodoACLListCommand() *cobra.Command {
 		ValidArgsFunction: cobra.NoFileCompletions,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of ACL entries to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -1428,7 +1510,10 @@ func newTodoWebhookCreateCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		id := getTrackerID(c, ctx, name, owner)
+		id, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		var config todosrht.TrackerWebhookInput
 		config.Url = url
@@ -1466,6 +1551,7 @@ func newTodoWebhookCreateCommand() *cobra.Command {
 }
 
 func newTodoWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -1512,12 +1598,12 @@ func newTodoWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = user.Tracker.Webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(user.Tracker.Webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -1531,6 +1617,8 @@ func newTodoWebhookListCommand() *cobra.Command {
 		ValidArgsFunction: completeTracker,
 		Run:               run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -1617,6 +1705,7 @@ func newTodoUserWebhookCreateCommand() *cobra.Command {
 }
 
 func newTodoUserWebhookListCommand() *cobra.Command {
+	var count int
 	run := func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 		c := createClient("todo", cmd)
@@ -1633,12 +1722,12 @@ func newTodoUserWebhookListCommand() *cobra.Command {
 			}
 
 			cursor = webhooks.Cursor
-			if cursor == nil {
+			if p.IsDone(cursor, len(webhooks.Results)) {
 				return pagerDone
 			}
 
 			return nil
-		})
+		}, count)
 		if err != nil {
 			log.Fatal(err)
 		}
@@ -1650,6 +1739,8 @@ func newTodoUserWebhookListCommand() *cobra.Command {
 		Args:  cobra.ExactArgs(0),
 		Run:   run,
 	}
+	cmd.Flags().IntVar(&count, "count", 0, "number of webhooks to fetch")
+	cmd.RegisterFlagCompletionFunc("count", cobra.NoFileCompletions)
 	return cmd
 }
 
@@ -1697,7 +1788,10 @@ func newTodoTicketCreateCommand() *cobra.Command {
 			log.Fatal(err)
 		}
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, name, owner)
+		trackerID, err := getTrackerID(c, ctx, name, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		var input todosrht.SubmitTicketInput
 		if stdin {
@@ -1850,7 +1944,10 @@ func newTodoTicketLabelCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, trackerName, owner)
+		trackerID, err := getTrackerID(c, ctx, trackerName, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		labelID, err := getLabelID(c, ctx, trackerName, labelName, owner)
 		if err != nil {
@@ -1889,7 +1986,10 @@ func newTodoTicketUnlabelCommand() *cobra.Command {
 		}
 
 		c := createClientWithInstance("todo", cmd, instance)
-		trackerID := getTrackerID(c, ctx, trackerName, owner)
+		trackerID, err := getTrackerID(c, ctx, trackerName, owner)
+		if err != nil {
+			log.Fatal(err)
+		}
 
 		labelID, err := getLabelID(c, ctx, trackerName, labelName, owner)
 		if err != nil {
@@ -1917,7 +2017,7 @@ func newTodoTicketUnlabelCommand() *cobra.Command {
 	return cmd
 }
 
-func getTrackerID(c *Client, ctx context.Context, name, owner string) int32 {
+func getTrackerID(c *Client, ctx context.Context, name, owner string) (int32, error) {
 	var (
 		user     *todosrht.User
 		username string
@@ -1931,14 +2031,14 @@ func getTrackerID(c *Client, ctx context.Context, name, owner string) int32 {
 		user, err = todosrht.TrackerIDByUser(c.Client, ctx, username, name)
 	}
 	if err != nil {
-		log.Fatalf("failed to get tracker ID: %v", err)
+		return 0, fmt.Errorf("failed to get tracker ID: %v", err)
 	} else if user == nil {
-		log.Fatalf("user %q does not exist", username)
+		return 0, fmt.Errorf("user %q does not exist", username)
 	} else if user.Tracker == nil {
-		log.Fatalf("tracker %q does not exist", name)
+		return 0, fmt.Errorf("tracker %q does not exist", name)
 	}
 
-	return user.Tracker.Id
+	return user.Tracker.Id, nil
 }
 
 func getTrackerName(ctx context.Context, cmd *cobra.Command) (name, owner, instance string, err error) {
